# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Business Applications
#    Copyright (C) 2004-2012 OpenERP S.A. (<http://openerp.com>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

import logging

from openerp.osv import fields, osv

_logger = logging.getLogger(__name__)

class adhoc_base_configuration(osv.osv_memory):
    _name = 'adhoc.base.config.settings'
    _inherit = 'res.config.settings'

    _columns = {
        'module_account_cancelled_invoice_number': fields.boolean('Show Cancelled Invoice Nunmber',
            help = """Installs the account_cancelled_invoice_number module."""),
        'module_account_check': fields.boolean('Checks Management, issued and third checks',
            help = """Installs the account_check module."""),
        'module_account_interests': fields.boolean('Interests management.',
            help = """Installs the account_interests module."""),
        'module_account_invoice_commercial': fields.boolean('Use commercial on invoices related to partner',
            help = """Installs the account_invoice_commercial module, will also install stock module as it change invoice creation from stock."""),
        'module_account_invoice_show_next_number': fields.boolean('Show next number on invoices',
            help = """Installs the account_invoice_show_next_number module."""),
        'module_account_partner_balance': fields.boolean('Aeroo Partner Balance Report',
            help = """Installs the account_partner_balance module."""),
        'module_account_supplier_invoice_number': fields.boolean('Show Suppplier Invoice Number on Supplier Invoice tree view',
            help = """Installs the account_supplier_invoice_number module."""),
        'module_account_voucher_receipt': fields.boolean('Generate receipts on vouchers',
            help = """Installs the account_voucher_receipt module."""),
        'module_journal_security': fields.boolean('Restrict users to some journals',
            help = """Installs the journal_security module."""),
        
        # Sale / Purchase modules
        'module_purchase_discounts': fields.boolean('Mange disccounts on purchases',
            help = """Installs the purchase_discounts module."""),
        'module_sale_prices_update': fields.boolean('Add update system for sale order lines',
            help = """Installs the sale_prices_update module."""),
        'module_sale_order_validity': fields.boolean('Mange Sale Orders Validity',
            help = """Installs the sale_order_validity module."""),
        
        # Tools modules
        'module_mail_local_server_catchall': fields.boolean('Configure catchall on local server',
            help = """Installs the mail_local_server_catchall module."""),

        # Partner modules
        'module_partner_person': fields.boolean('Add person information to partners.',
            help = """Installs the partner_person module. Add firstname, lastname, birthdate, etc."""),
        'module_partner_social_fields': fields.boolean('Add social fields to partners',
            help = """Installs the partner_social_fields module."""),
        'module_partner_user': fields.boolean('Add user quick creation from partners',
            help = """Installs the partner_user module."""),

        # Product modules
        'module_product_pack': fields.boolean('Mange product packs',
            help = """Installs the product_pack module."""),
        'module_product_pack_sale_order_warning': fields.boolean('Mange stock warnings on product packs',
            help = """Installs the product_pack_sale_order_warning module."""),
        'module_product_price_currency': fields.boolean('Manage different currencies on product sale price',
            help = """Installs the product_price_currency module."""),
        'module_product_dimensions': fields.boolean('Manage product dimmensions',
            help = """Installs the product_dimensions module."""),
        'module_product_supplier_pricelist': fields.boolean('Mange easier supplier pricelist',
            help = """Installs the product_supplier_pricelist module."""),
        'module_product_unique': fields.boolean('Validate product unicity per company on ean13 and interal reference fields',
            help = """Installs the product_unique module."""),
    }        
    
    _defaults = {
    }

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
